@@ -202,7 +202,8 @@ class FunctorPool:
 
     def __init__(self, workers: List[BaseFunctorWorker[T, R]], context: Optional[BaseContext] = None,
                  work_queue_maxsize: Optional[Union[int, float]] = 1.0,
-                 results_queue_maxsize: Optional[Union[int, float]] = None, verbose: float = False):
+                 results_queue_maxsize: Optional[Union[int, float]] = None, verbose: float = False,
+                 join_timeout: Optional[int] = None):
         """
         Initialization of pool.
 
@@ -216,6 +217,7 @@ class FunctorPool:
             float the max size will be: int(workers * results_queue_maxsize)
             int the max size is just results_queue_maxsize
         :param verbose: Determines whether information messages should be shown.
+        :param join_timeout: Timout for process joining.
         """
 
         if context is None:
@@ -239,6 +241,7 @@ class FunctorPool:
             self._init_process(p)
 
         self.verbose = verbose
+        self.join_timeout = join_timeout
 
     def _init_process(self, p: BaseFunctorWorker):
         """
@@ -264,7 +267,7 @@ class FunctorPool:
             self._work_queue.put(None)
         for p in self.procs:
             if p.exitcode is None:
-                p.join(timeout=60)
+                p.join(timeout=self.join_timeout)
                 if p.exitcode is None and self.verbose:
                     print(f"Process with wid {p.wid} was not joined and is still running.", file=sys.stderr)
 
